@@ -3,36 +3,41 @@
 use strict;
 use warnings;
 
+use Getopt::Long;
+
 use IO::Async::Loop;
-use IO::Async::Stream;
 use IO::Async::Listener;
 
 my $PORT = 12345;
+my $FAMILY;
+my $V6ONLY;
+
+GetOptions(
+   'port|p=i' => \$PORT,
+   '4'        => sub { $FAMILY = "inet" },
+   '6'        => sub { $FAMILY = "inet6" },
+   'v6only=i' => \$V6ONLY,
+) or exit 1;
 
 my $loop = IO::Async::Loop->new;
 
 my $listener = IO::Async::Listener->new(
-   on_accept => sub {
+   on_stream => sub {
       my $self = shift;
-      my ( $socket ) = @_;
+      my ( $stream ) = @_;
 
-      # $socket is just an IO::Socket reference
+      my $socket = $stream->read_handle;
       my $peeraddr = $socket->peerhost . ":" . $socket->peerport;
 
       print STDERR "Accepted new connection from $peeraddr\n";
 
-      my $clientstream = IO::Async::Stream->new(
-         handle => $socket,
-
+      $stream->configure(
          on_read => sub {
-            my ( $self, $buffref, $closed ) = @_;
+            my ( $self, $buffref, $eof ) = @_;
 
-            if( $$buffref =~ s/^(.*\n)// ) {
+            while( $$buffref =~ s/^(.*\n)// ) {
                # eat a line from the stream input
-               my $line = $1;
-               $self->write( $line );
-
-               return 1;
+               $self->write( $1 );
             }
 
             return 0;
@@ -43,7 +48,7 @@ my $listener = IO::Async::Listener->new(
          },
       );
 
-      $loop->add( $clientstream );
+      $loop->add( $stream );
    },
 );
 
@@ -52,9 +57,11 @@ $loop->add( $listener );
 $listener->listen(
    service  => $PORT,
    socktype => 'stream',
+   family   => $FAMILY,
+   v6only   => $V6ONLY,
 
    on_resolve_error => sub { die "Cannot resolve - $_[0]\n"; },
    on_listen_error  => sub { die "Cannot listen\n"; },
 );
 
-$loop->loop_forever;
+$loop->run;
