@@ -9,7 +9,7 @@ use 5.010; # //
 use strict;
 use warnings;
 
-our $VERSION = '0.61';
+our $VERSION = '0.64';
 
 use base qw( IO::Async::Timer::Periodic );
 
@@ -91,28 +91,24 @@ L<File::stat> instances containing the old and new C<stat()> fields.
 
 The following named parameters may be passed to C<new> or C<configure>.
 
-=over 8
-
-=item handle => IO
+=head2 handle => IO
 
 The opened filehandle to watch for C<stat()> changes if C<filename> is not
 supplied.
 
-=item filename => STRING
+=head2 filename => STRING
 
 Optional. If supplied, watches the named file rather than the filehandle given
 in C<handle>. The file will be opened for reading and then watched for
 renames. If the file is renamed, the new filename is opened and tracked
 similarly after closing the previous file.
 
-=item interval => NUM
+=head2 interval => NUM
 
 Optional. The interval in seconds to poll the filehandle using C<stat(2)>
 looking for size changes. A default of 2 seconds will be applied if not
 defined.
 
-=back
-
 =cut
 
 sub _init
@@ -149,6 +145,17 @@ sub configure
    $self->SUPER::configure( %params );
 }
 
+sub _add_to_loop
+{
+   my $self = shift;
+
+   if( !defined $self->{filename} and !defined $self->{handle} ) {
+      croak "IO::Async::File needs either a filename or a handle";
+   }
+
+   return $self->SUPER::_add_to_loop( @_ );
+}
+
 sub _reopen_file
 {
    my $self = shift;
